@@ -1,4 +1,10 @@
-getFrequency <- function(matrix,varnames,groupvar,groups,labels,stats,format){
+getFrequency <- function(matrix,
+                         varnames,
+                         groupvar,
+                         groups,
+                         labels,
+                         stats,
+                         format,digits,big.mark=","){
     totals <- vector(NCOL(matrix),mode="list")
     xlevels <- vector(NCOL(matrix),mode="list")
     names(totals) <- varnames
@@ -24,12 +30,17 @@ getFrequency <- function(matrix,varnames,groupvar,groups,labels,stats,format){
             perc.v <- rep(100,length(names(tab.v)))
         ## avoid NA when 0/0
         perc.v[s.tab.v==0] <- 0
+        # format percent
+        perc.v <- lapply(perc.v,function(p){
+            sprintf(fmt=paste("%1.",digits,"f",sep=""),p)
+        })
         totals[[v]] <- sapply(1:length(perc.v),function(i){
             values <- list(tab.v[i],total.v,perc.v[i])
             if ("colpercent" %in% stats)
                 names(values) <- c("count","total","colpercent")
             else
                 names(values) <- c("count","total","percent")
+            if (big.mark!="") values[["count"]] <- format(values[["count"]],big.mark=big.mark,scientific=FALSE)
             do.call("sprintf",c(format,values[stats]))
         })
         ## 
@@ -42,6 +53,8 @@ getFrequency <- function(matrix,varnames,groupvar,groups,labels,stats,format){
                     xtab$Percent <- 100*xtab$Freq/sum(xtab$Freq)
                     ## avoid NA when 0/0
                     xtab$Percent[xtab$Freq==0] <- 0
+                    # format percent
+                    xtab$Percent <- sprintf(fmt=paste("%1.",digits,"f",sep=""),xtab$Percent)
                 }
                 tab.out <- lapply(1:NROW(xtab),function(row){
                     values <- xtab[row,-1]
@@ -51,6 +64,7 @@ getFrequency <- function(matrix,varnames,groupvar,groups,labels,stats,format){
                     else{
                         vals <- as.list(unlist(values))
                         if (pos.count <- match("count",stats,nomatch=FALSE)){
+                            if (big.mark!="") vals[["Freq"]] <- format(as.numeric(vals[["Freq"]]),big.mark=big.mark,scientific=FALSE)
                             if (pos.count==1)
                                 do.call("sprintf",c(format,vals))
                             else # pos.count==2
@@ -70,12 +84,16 @@ getFrequency <- function(matrix,varnames,groupvar,groups,labels,stats,format){
                     colp <- 100*val/sum(val)
                     ## avoid NA when 0/0
                     colp[sum(val)==0] <- 0
+                    # format percent
+                    colp <- sprintf(fmt=paste("%1.",digits,"f",sep=""),colp)
                     if (pos.count <- match("count",stats,nomatch=FALSE)){
+                        if (big.mark!="") val <- format(val,big.mark=big.mark,scientific=FALSE)
                         sapply(1:length(val),function(i){
-                            if (pos.count==1)
+                            if (pos.count==1){
                                 do.call("sprintf",c(format,as.list(c(val[i],colp[i]))))
-                            else # pos.count==2
+                            } else{ # pos.count==2
                                 do.call("sprintf",c(format,as.list(c(colp[i],val[i]))))
+                            }
                         })
                     }else{ ## show colpercent without count
                         sapply(1:length(val),function(i){
