@@ -27,6 +27,7 @@
 ##' summary(regressionTable(fit),handler="prettyNum")
 ##' summary(regressionTable(fit),handler="format")
 ##' summary(regressionTable(fit),handler="sprintf",digits=c(2,2),pValue.stars=TRUE)
+##' summary(regressionTable(fit),handler="sprintf",digits=c(2,2),pValue.stars=TRUE,ci.format="(l,u)")
 #' @export 
 ##' @author Thomas A. Gerds <tag@@biostat.ku.dk>
 summary.regressionTable <- function(object,
@@ -105,6 +106,8 @@ summary.regressionTable <- function(object,
         }
     }
     ## cat("\nSignif. codes:  0 '***'0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1\n")
+    ## FIXME: should filter the relevant of list(...)
+    Rtab <- do.call(labelUnits,c(list(x=Rtab),list(...)))
     res <- list(regressionTable=Rtab,
                 rawTable=rawtab,
                 model=model,
